@@ -3,9 +3,9 @@ from __future__ import annotations
 from functools import cached_property
 from typing import TYPE_CHECKING
 
+from pls import globals
 from pls.fs.git import formatted_status
 from pls.models.base_node import BaseNode
-from pls.state import state
 
 
 if TYPE_CHECKING:
@@ -24,10 +24,12 @@ class GitMixin(BaseNode):
         self.path_wrt_git: Optional[Path] = None
         self.git_status: str = "  "
 
-        if state.is_git_managed:
+        if globals.state.git_root is not None:
             try:
-                self.path_wrt_git = self.path.relative_to(state.git_root)
-                self.git_status = state.git_status_map.get(self.path_wrt_git, "  ")
+                self.path_wrt_git = self.path.relative_to(globals.state.git_root)
+                self.git_status = globals.state.git_status_map.get(
+                    self.path_wrt_git, "  "
+                )
             except ValueError:
                 # This is dest node for absolute symlink to file outside Git repo.
                 pass
@@ -36,7 +38,7 @@ class GitMixin(BaseNode):
     def git_cells(self) -> dict[str, str]:
         """mapping of detail keys to the corresponding formatted Git-status"""
 
-        if not state.is_git_managed:
+        if globals.state.git_root is None:
             return {}
 
         cells = {"git": formatted_status(self.git_status)}
